@@ -21,7 +21,7 @@ class CmdMQTTClient(object):
         self.__parser = optparse.OptionParser(usage="%prog [-p UDS_PUB] "
                                                     "[-s] { -c { C | G | P | S | X } (UDS_SUB_1) | "
                                                     "[SUB_TOPIC_1 (UDS_SUB_1) .. SUB_TOPIC_N (UDS_SUB_N)] } "
-                                                    "[-n] [-e] [-v]", version="%prog 1.0")
+                                                    "[-n] [-t] [-e] [-v]", version="%prog 1.0")
 
         # optional...
         self.__parser.add_option("--pub", "-p", type="string", nargs=1, action="store", dest="uds_pub",
@@ -36,6 +36,9 @@ class CmdMQTTClient(object):
         self.__parser.add_option("--no-wrapper", "-n", action="store_true", dest="no_wrapper", default=False,
                                  help="discard topic wrapper")
 
+        self.__parser.add_option("--timed", "-t", action="store_true", dest="timed", default=False,
+                                 help="add a field for received datetime")
+
         self.__parser.add_option("--echo", "-e", action="store_true", dest="echo", default=False,
                                  help="echo input to stdout (if not writing subscriptions to stdout)")
 
@@ -107,6 +110,11 @@ class CmdMQTTClient(object):
         return self.__opts.no_wrapper
 
 
+    @property
+    def timed(self):
+        return self.__opts.timed
+
+
     @property
     def wrap(self):
         return not self.__opts.no_wrapper
@@ -129,10 +137,10 @@ class CmdMQTTClient(object):
 
 
     def __str__(self, *args, **kwargs):
-        return "CmdMQTTClient:{subscriptions:%s, channel:%s, channel_uds:%s, uds_pub:%s, no_wrapper:%s, " \
-               "echo:%s, verbose:%s}" % \
-               (Str.collection(self.subscriptions), self.channel, self.channel_uds, self.uds_pub, self.no_wrapper,
-                self.echo, self.verbose)
+        return "CmdMQTTClient:{subscriptions:%s, channel:%s, channel_uds:%s, uds_pub:%s, " \
+               "timed:%s, no_wrapper:%s, echo:%s, verbose:%s}" % \
+               (Str.collection(self.subscriptions), self.channel, self.channel_uds, self.uds_pub,
+                self.timed, self.no_wrapper, self.echo, self.verbose)
 
 
 # --------------------------------------------------------------------------------------------------------------------
